Crate smart_leds_trait

Crate smart_leds_trait 

Smart Leds Trait

Smart leds is a collection of crates to use smart leds on embedded devices with rust.

Examples of smart leds include the popular WS2812 (also called Neopixel), APA102 (DotStar) and other leds, which can be individually adressed.

This crate is used as a common base, so that breaking changes which would force all other crates to be updated, can be avoided.

End users should use the smart-leds crate, which contains various convenience functions.

Structs

CctWhite
RGB
The RGB pixel
RGBA
The RGBA pixel
White

Traits

SmartLedsWrite
A trait that Smart Led Drivers implement
SmartLedsWriteAsync
An async trait that Smart Led Drivers implement

Type Aliases

RGB8
8-bit RGB
RGB16
16-bit RGB in machine’s native endian
RGBCCT
The RGBCCT Pixel
RGBW
The RGBW Pixel